@@ -39,12 +39,11 @@ from hypothesis._settings import (
     Verbosity,
     note_deprecation,
     settings as Settings,
-    unlimited,
 )
 from hypothesis.control import current_build_context
 from hypothesis.core import given
 from hypothesis.errors import InvalidArgument, InvalidDefinition
-from hypothesis.internal.compat import int_to_bytes, string_types
+from hypothesis.internal.compat import string_types
 from hypothesis.internal.reflection import function_digest, nicerepr, proxies
 from hypothesis.internal.validation import check_type
 from hypothesis.reporting import current_verbosity, report
@@ -83,11 +82,7 @@ def run_state_machine_as_test(state_machine_factory, settings=None):
             settings = state_machine_factory.TestCase.settings
             check_type(Settings, settings, "state_machine_factory.TestCase.settings")
         except AttributeError:
-            settings = Settings(
-                timeout=unlimited,
-                deadline=None,
-                suppress_health_check=HealthCheck.all(),
-            )
+            settings = Settings(deadline=None, suppress_health_check=HealthCheck.all())
     check_type(Settings, settings, "settings")
 
     @settings
@@ -229,11 +224,7 @@ class GenericStateMachine(
             pass
 
         class StateMachineTestCase(TestCase):
-            settings = Settings(
-                timeout=unlimited,
-                deadline=None,
-                suppress_health_check=HealthCheck.all(),
-            )
+            settings = Settings(deadline=None, suppress_health_check=HealthCheck.all())
 
         # We define this outside of the class and assign it because you can't
         # assign attributes to instance method values in Python 2
@@ -628,8 +619,7 @@ class RuleStrategy(SearchStrategy):
         # Easy, right?
         n = len(self.rules)
         i = cu.integer_range(data, 0, n - 1)
-        u, v = data.blocks[-1].bounds
-        block_length = v - u
+        block_length = data.blocks[-1].length
         rule = self.rules[i]
         if not self.is_valid(rule):
             valid_rules = [j for j, r in enumerate(self.rules) if self.is_valid(r)]
@@ -638,7 +628,9 @@ class RuleStrategy(SearchStrategy):
                     u"No progress can be made from state %r" % (self.machine,)
                 )
             i = valid_rules[cu.integer_range(data, 0, len(valid_rules) - 1)]
-            data.write(int_to_bytes(i, block_length))
+            # Insert a copy of ``i`` into the data stream to make it easier for
+            # the shrinker to delete the initial invalid rule draw.
+            data.draw_bits(block_length * 8, forced=i)
             rule = self.rules[i]
         return (rule, data.draw(rule.arguments_strategy))
 
